[![PyPI version](https://badge.fury.io/py/types-wxpython.svg)](https://badge.fury.io/py/types-wxpython)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-wxpython)
![GitHub branch checks state](https://img.shields.io/github/checks-status/AlexionSoftware/types-wxpython/main)
![PyPI - Downloads](https://img.shields.io/pypi/dm/types-wxpython)
![GitHub](https://img.shields.io/github/license/AlexionSoftware/types-wxpython)

# Typing stubs for wxPython
Version: wxPython 4.2.0

This package contains typings stubs for [wxPython](https://pypi.org/project/wxPython/)

This package is not maintained by the maintainers of wxPython. This is made by users of wxPython.

Any help is always welcome.
